@@ -8,7 +8,7 @@ Created on Fri Sep 23 21:41:10 2022
 
 import qesdk
 qesdk.auth('quantease','$1$$k7yjPQKv8AJuZERDA.eQX.')
-print(qesdk.check_auth())
+#print(qesdk.check_auth())
 '''
 qesdk.login('scott','12345678')
 stratlist=(qesdk.sm_get_clone_strat_list())
@@ -16,7 +16,7 @@ print('strats',stratlist)
 if stratlist and isinstance(stratlist,list) and len(stratlist) > 0:
     print(qesdk.sm_get_clone_strat_position(stratlist))
 '''
-df = qesdk.get_product_invent_orders('CU', '2023-02-01','2023-02-14')
+df = qesdk.get_product_invent_orders('CU', '2023-02-01','2023-02-14').diff(1)
 print(df)
     
 #qesdk.auth('quantease','$1$$k7yjPQKv8AJuZERDA.eQX.')
